timeseria.models.anomaly\_detectors
===================================

.. automodule:: timeseria.models.anomaly_detectors

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      AnomalyDetector
      ForecasterAnomalyDetector
      PeriodicAverageAnomalyDetector
   
   

   
   
   



